@@ -24,9 +24,9 @@
 #include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
 
 #include <gtkmm.h>
-#include <glom/libglom/data_structure/field.h>
+#include <libglom/data_structure/field.h>
 #include "comboglomchoicesbase.h"
-#include <libglademm.h>
+#include <gtkmm/builder.h>
 
 namespace Glom
 {
@@ -38,7 +38,7 @@ class ComboEntryGlom
   public ComboGlomChoicesBase
 {
 public:
-  explicit ComboEntryGlom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+  explicit ComboEntryGlom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
 
   ///You must call set_layout_item() to specify the field type and formatting of the main column.
   explicit ComboEntryGlom();
@@ -62,7 +62,7 @@ public:
 
   virtual void set_read_only(bool read_only = true);
 
-protected:
+private:
   void init();
 
 
